@@ -104,19 +104,11 @@ function install() {
     fi
     echo "perl-Net-LDAP-Serverをインストールしました。"
 
-    rpm -Uvh ./software/perl-VUser-Google-ProvisioningAPI-*-[0-9]*.secioss.noarch.rpm >> $LOG 2>&1
-    if [ $? -ne 0 ]; then
-        echo "perl-VUser-Google-ProvisioningAPIのインストールに失敗しました。"
-        rpm -e perl-Net-LDAP-Server
-        return 1
-    fi
-    echo "perl-VUser-Google-ProvisioningAPIをインストールしました。"
-
     rpm -Uvh ./software/openldap23-2.3.[0-9]*-[0-9]*.secioss.*.rpm \
              ./software/openldap23-servers-2.3.[0-9]*-[0-9]*.secioss.*.rpm >> $LOG 2>&1
     if [ $? -ne 0 ]; then
         echo "openldapのインストールに失敗しました。"
-        rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI
+        rpm -e perl-Net-LDAP-Server
         return 1
     fi
     echo "openldapをインストールしました。"
@@ -124,7 +116,7 @@ function install() {
     rpm -Uvh ./software/perl-LISM-[0-9]*.[0-9]*.[0-9]*-[0-9]*.secioss.noarch.rpm >> $LOG 2>&1
     if [ $? -ne 0 ]; then
         echo "LISMのインストールに失敗しました。"
-        rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI openldap23 openldap23-servers
+        rpm -e perl-Net-LDAP-Server openldap23 openldap23-servers
         return 1
     fi
     echo "LISMをインストールしました。"
@@ -134,7 +126,7 @@ function install() {
         rpm -Uvh ./software/php-Secioss-AutoLogin-*.secioss.noarch.rpm >> $LOG 2>&1
         if [ $? -ne 0 ]; then
             echo "php-Secioss-AutoLoginのインストールに失敗しました。"
-            rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI openldap23 openldap23-servers perl-LISM
+            rpm -e perl-Net-LDAP-Server openldap23 openldap23-servers perl-LISM
             return 1
         fi
         echo "php-Secioss-AutoLoginをインストールしました。"
@@ -145,7 +137,7 @@ function install() {
         rpm -Uvh ./software/access-manager-apps-*.secioss.noarch.rpm >> $LOG 2>&1
         if [ $? -ne 0 ]; then
             echo "access-manager-appsのインストールに失敗しました。"
-            rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin
+            rpm -e perl-Net-LDAP-Server openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin
             return 1
         fi
         echo "access-manager-appsをインストールしました。"
@@ -154,7 +146,7 @@ function install() {
     rpm -Uvh ./software/simplesamlphp-*.rpm >> $LOG 2>&1
     if [ $? -ne 0 ]; then
         echo "simplesamlphpのインストールに失敗しました。"
-        rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin access-manager-apps
+        rpm -e perl-Net-LDAP-Server openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin access-manager-apps
         return 1
     fi
     echo "simplesamlphpをインストールしました。"
@@ -162,7 +154,7 @@ function install() {
     rpm -Uvh ./software/php-pecl-filter-*.rpm >> $LOG 2>&1
     if [ $? -ne 0 ]; then
         echo "php-pecl-filterのインストールに失敗しました。"
-        rpm -e perl-Net-LDAP-Server perl-VUser-Google-ProvisioningAPI openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin access-manager-apps simplesamlphp
+        rpm -e perl-Net-LDAP-Server openldap23 openldap23-servers perl-LISM php-Secioss-AutoLogin access-manager-apps simplesamlphp
         return 1
     fi
     echo "php-pecl-filterをインストールしました。"
@@ -181,8 +173,8 @@ function install() {
     cp ./conf/saml20* /usr/share/simplesamlphp/metadata/
     cp ./src/oauth2/oauth.conf /var/www/conf/
     chown ldap.apache /opt/secioss/etc/lism.conf
-    cp ./conf/{lism.conf,lism-sp.conf} /opt/secioss/etc/
-    chown ldap.apache /opt/secioss/etc/{lism.conf,lism-sp.conf}
+    cp ./conf/{lism.conf,lism-sp.conf,lism-idp.conf} /opt/secioss/etc/
+    chown ldap.apache /opt/secioss/etc/{lism.conf,lism-sp.conf,lism-idp.conf}
     chmod 660 /opt/secioss/etc/lism.conf
     chown apache /opt/secioss/var/lib/ldap
     chmod 770 /opt/secioss/var/lib/ldap
@@ -209,13 +201,6 @@ function update() {
     fi
     echo "perl-Net-LDAP-Serverをアップデートしました。"
 
-    rpm -Fvh ./software/perl-VUser-Google-ProvisioningAPI-*-[0-9]*.secioss.noarch.rpm >> $LOG 2>&1
-    if [ $? -ne 0 ]; then
-        echo "perl-VUser-Google-ProvisioningAPIのアップデートに失敗しました。"
-        return 1
-    fi
-    echo "perl-VUser-Google-ProvisioningAPIをアップデートしました。"
-
     rpm -Fvh ./software/openldap23-2.3.[0-9]*-[0-9]*.secioss.*.rpm \
              ./software/openldap23-servers-2.3.[0-9]*-[0-9]*.secioss.*.rpm >> $LOG 2>&1
     if [ $? -ne 0 ]; then
@@ -313,13 +298,6 @@ function uninstall() {
         echo "openldapをアンインストールしました。"
     fi
 
-    rpm -e perl-VUser-Google-ProvisioningAPI >> $LOG 2>&1
-    if [ $? -ne 0 ]; then
-        echo "perl-VUser-Google-ProvisioningAPIのアンインストールに失敗しました。"
-    else
-        echo "perl-VUser-Google-ProvisioningAPIをアンインストールしました。"
-    fi
-
     rpm -e perl-Net-LDAP-Server >> $LOG 2>&1
     if [ $? -ne 0 ]; then
         echo "perl-Net-LDAP-Serverのアンインストールに失敗しました。"
