@@ -447,12 +447,15 @@ sub _checkConfig
             } elsif ($type eq 'lism') {
                 if (!defined($self->{lismmap})) {$self->{lismmap} = {}};
                 my $lismmap = {};
-                my ($base, $attr, $scope) = split(/\?/, $conf->{rewritemap}{$map_name}->{attrs});
+                my ($base, $attr, $scope, $sizelimit) = split(/\?/, $conf->{rewritemap}{$map_name}->{attrs});
                 $lismmap->{base} = $base;
                 $lismmap->{attr} = $attr;
                 if ($scope) {
                     $lismmap->{scope} = $scope;
                 }
+                if ($sizelimit) {
+                    $lismmap->{sizelimit} = $sizelimit;
+                }
                 $self->{lismmap}{$map_name} = $lismmap;
             }
         }
@@ -461,7 +464,7 @@ sub _checkConfig
     if (defined($conf->{rewrite})) {
         foreach my $rule (@{$conf->{rewrite}}) {
             if (defined($rule->{filter})) {
-                $rule->filter =~ s/&amp;/&/g;
+                $rule->{filter} =~ s/&amp;/&/g;
                 $rule->{filterobj} = Net::LDAP::Filter->new(encode('utf8', $rule->{filter}));
             }
             if (defined($rule->{attrs})) {
@@ -472,6 +475,7 @@ sub _checkConfig
             # enable escape sequence
             $rule->{substitution} =~ s/([^\\])\\n/$1\n/g;
             $rule->{substitution} =~ s/([^\\])\\t/$1\t/g;
+            $rule->{substitution} =~ s/&amp;/&/g;
         }
     }
 
