@@ -12,6 +12,7 @@
 require_once("PEAR.php");
 require_once("HTTP/Request.php");
 
+define('ALCOOKIE', 'secioss_autologin');
 define('PWD_LEN', 8);
 if (strtoupper(substr(PHP_OS, 0, 3)) !== 'WIN') {
     define('WINPWDCMD', '/opt/secioss/sbin/chwinpasswd');
@@ -336,6 +337,7 @@ class AutoLogin
         $body = '';
         $cookies = array();
         foreach ($_COOKIE as $key => $value) {
+            if ($key == ALCOOKIE) continue;
             $cookies[$key] = array('name' => $key, 'value' => $value);
         }
         foreach ($this->cookie as $key => $value) {
@@ -439,6 +441,7 @@ class AutoLogin
             }
         }
 
+        $appcookies = isset($_COOKIE[ALCOOKIE]) ? preg_split('/#/', $_COOKIE[ALCOOKIE]) : array();
         if (is_array($cookies)) {
             foreach ($cookies as $key => $cookie) {
                 if ($cookie['name'] == 'auth_tkt') {
@@ -447,11 +450,29 @@ class AutoLogin
                 if (preg_match('/[,; \t\r\n]/', $cookie['value'])) {
                     $cookie['value'] = base64_encode($cookie['value']);
                 }
-                if (!setrawcookie($cookie['name'], $cookie['value'], isset($cookie['expires']) ? strtotime($cookie['expires']) : 0, isset($cookie['path']) && (!isset($this->url['back']) || preg_match('#^'.$cookie['path'].'#', preg_replace('#^https?://[^/]+#', '', $this->url['back']))) ? $cookie['path'] : '/', $domain, isset($cookie['secure']) ? $cookie['secure'] : false)) {
+                if (isset($cookie['path'])) {
+                    if (isset($this->options['rewrite_cookiepath']) && $this->options['rewrite_cookiepath']) {
+                        list($match, $substitute) = preg_split('/, */', $this->options['rewrite_cookiepath']);
+                        $cookiepath = preg_replace('#^'.$match.'$#', $substitute, $cookie['path']);
+                    } else if (!isset($this->url['back']) || preg_match('#^'.$cookie['path'].'#', preg_replace('#^https?://[^/]+#', '', $this->url['back']))) {
+                        $cookiepath = $cookie['path'];
+                    } else {
+                        $cookiepath = '/';
+                    }
+                } else {
+                    $cookiepath = '/';
+                }
+                if (!setrawcookie($cookie['name'], $cookie['value'], isset($cookie['expires']) ? strtotime($cookie['expires']) : 0, $cookiepath, $domain, isset($cookie['secure']) ? $cookie['secure'] : false)) {
                     return PEAR::raiseError("Can't set cookie ".$cookie['name'], AUTO_LOGIN_ERROR);
                 }
+                if (isset($this->options['cookiename']) && $this->options['cookiename'] == $cookie['name']) {
+                    array_push($appcookies, $cookie['name']."=$cookiepath");
+                }
             }
         }
+        if (count($appcookies)) {
+            setcookie(ALCOOKIE, join('#', $appcookies), 0, null, $domain);
+        }
 
         if (isset($this->url['back'])) {
             $back = $this->url['back'];
@@ -604,6 +625,11 @@ class AutoLogin
         return $rc;
     }
 
+    function deletePasswd()
+    {
+        return $this->storage->deletePassword($this->app);
+    }
+
     // {{{ updateSecret()
     /**
      * added by okazaki 20090710
@@ -613,28 +639,28 @@ class AutoLogin
      * @param  string   $secret       シークレット
      * @return mixed    true:正常終了 PEAR_Error:エラー
      */
-    function updateSecret($secret = null)
+    function updateSecret($secret, $pin = null)
     {
         $rc = 0;
 
         if (!$this->app) {
-            $rc = $this->storage->validateSecret($secret);
+            $rc = $this->storage->validateSecret($secret, $pin);
         }
         if ($rc) {
             switch($rc) {
               case AUTO_LOGIN_INVALID_VALUE:
-                $message = "Invalid secret";
+                $message = "Invalid secret or PIN";
                 break;
             }
             return PEAR::raiseError($message, $rc);
         }
 
-        return $this->storage->setSecret($secret);
+        return $this->storage->setSecret($secret, $pin);
     }
 
-    function getTenants()
+    function getTenants($tenant = null)
     {
-        return $this->storage->getTenants();
+        return $this->storage->getTenants($tenant);
     }
 
     // {{{ _factory()
