@@ -17,9 +17,13 @@ $session = SimpleSAML_Session::getInstance();
 
 $tenant = null;
 if ($session->getAttribute('tenant')) {
-        $tenant = $session->getAttribute('tenant');
-        $tenant = is_array($tenant) ? $tenant[0] : $tenant;
-        $_GET['tenant'] = $tenant;
+	$tenant = $session->getAttribute('tenant');
+} else if (isset($_SERVER['REMOTE_USER']) && preg_match('/@(.+)$/', $_SERVER['REMOTE_USER'], $matches)) {
+	$tenant = $matches[1];
+}
+if ($tenant) {
+	$tenant = is_array($tenant) ? $tenant[0] : $tenant;
+	$_GET['tenant'] = $tenant;
 }
 
 try {
